# Notes/Thoughts

## ChatGPT4
* ChatGPT4 is INCREDIBLY helpful in iterating when global and reasonably logical changes are needed.
* 10X more productive
* Accessibilit to tools I have no understanding of
* Can get in rabbit holes
* Can wildly misunderstand
* Needs patiece
* Needs appropriate expectations


## VSCode
* Code completion/suggestion from github repos is a godsend. Suggest things I never considered.